@@ -15,6 +15,14 @@
 Tests for testsetups in grok.testing
 ************************************
 
+.. warn:: Outdated!
+
+  While all the information herein is correct, there are more and
+  other options available with current version of `z3c.testsetup`.
+
+  See http://pypi.python.org/pypi/z3c.testsetup for up-to-date
+  information.
+
 The grok testing support provides a z3c.testsetup which should suit
 most grokprojects. Main parts of this support are
 
@@ -165,7 +173,7 @@ Basically, all files/modules are found that
 
    For unit doctests the file must contain::
 
-       :Test-Layer: functional
+       :Test-Layer: unit
 
    Python test modules must provide a module docstring that contains::
 
@@ -312,12 +320,14 @@ can use three options:
         ...     cave, filter_func = myfilter)
         >>> suite = setup()
         >>> get_basenames_from_suite(suite)
-        ['file1.py', 'subdirfile.txt', 'subdirfile.txt']
+        ['file1.py', 'subdirfile.txt', 'subdirfile.txt', 'subdirfile.txt']
 
      Again we see the one Python module. The module search is not
      affected by `filter_func`. Use `pfilter_func` instead::
 
         >>> def mypfilter(module):
+        ...     if not hasattr(module, '__file__'):
+        ...         return False
         ...     basename = os.path.basename(module.__file__)
         ...     if basename.startswith('subdirfile'):
         ...         return True
@@ -430,7 +440,7 @@ layer for functional doctests. We will therefore start with it.
 
     The testrunner is ready. Let's start it::
 
-       >>> testrunner.run(defaults)
+       >>> testrunner.run_internal(defaults)
        Running samplesetup1.CustomSampleLayer tests:
          Set up samplesetup1.CustomSampleLayer in ... seconds.
          Ran 2 tests with 0 failures and 0 errors in ... seconds.
@@ -462,7 +472,7 @@ layer for functional doctests. We will therefore start with it.
        ...     '--tests-pattern', '^samplesetup2$',
        ...     ]
        >>> sys.argv = 'test -f '.split()
-       >>> testrunner.run(defaults)
+       >>> testrunner.run_internal(defaults)
        Running grok.tests.testsetup.cave.CustomLayerFromPath tests:
          Set up grok.tests.testsetup.cave.CustomLayerFromPath in ... seconds.
          Ran 2 tests with 0 failures and 0 errors in ... seconds.
@@ -492,7 +502,7 @@ layer for functional doctests. We will therefore start with it.
        ...     '--tests-pattern', '^samplesetup3$',
        ...     ]
        >>> sys.argv = 'test -f '.split()
-       >>> testrunner.run(defaults)
+       >>> testrunner.run_internal(defaults)
        Running grok.tests.testsetup.cave.FunctionalLayer tests:
          Set up grok.tests.testsetup.cave.FunctionalLayer in ... seconds.
          Ran 2 tests with 0 failures and 0 errors in ... seconds.
@@ -525,7 +535,7 @@ layer for functional doctests. We will therefore start with it.
        ...     '--tests-pattern', '^samplesetup4$',
        ...     ]
        >>> sys.argv = 'test -f '.split()
-       >>> testrunner.run(defaults)
+       >>> testrunner.run_internal(defaults)
        Running grok.tests.testsetup.cave_to_let.GrokFunctionalLayer tests:
          Set up grok.tests.testsetup.cave_to_let.GrokFunctionalLayer in ... seconds.
          Ran 1 tests with 0 failures and 0 errors in ... seconds.
